@@ -257,6 +257,7 @@ def render_table(data, append_headers, append_lineno):
     length = 22
     n = math.ceil(len(data["rows"]) / length)
     html = []
+    rows = []
     for index in range(0, n+1):
         html.append(
             "<table  "
@@ -279,7 +280,14 @@ def render_table(data, append_headers, append_lineno):
         html.append("</colgroup>")
         append_headers(data, html)
 
-        for i, row in enumerate(data["rows"][index*length:(index+1)*length]):
+        if index > 0:
+            rows.append(data["rows"][0:2])
+            rows.append(data["rows"][index*length:(index+1)*length])
+        else :
+            rows.append(data["rows"][index*length:(index+1)*length])
+
+
+        for i, row in enumerate(rows):
             trow = [('<tr id="{}-{}-of-{}-for-data-{}-of-{}">').format(i, index, n,index*length,index+1*length)]
             append_lineno(trow, i)
             for cell in row:
